import { LitElement } from 'lit';
import { ComposedEvent } from '@patternfly/pfe-core';
export declare class DroplistSelectEvent extends ComposedEvent {
    value: string;
    constructor(value: string);
}
/**
 * Search Droplist
 * @csspart {HTMLULElement} listbox - The listbox element
 * @csspart {HTMLLIElement} option - Each search item.
 * @csspart {HTMLULElement} item-index-${n} - Each item in in the dropdown receives a 0-indexed `item-index-${n}` part
 *                                            e.g. `item-index-0`, `item-index-1`
 *
 * @fires {DroplistSelectEvent} select - When an option is selected.
 * @fires {CustomEvent<{ optionValue: string }>} pfe-autocomplete:option-selected {@deprecated Use `select`}
 */
export declare class PfeSearchDroplist extends LitElement {
    static readonly version = "{{version}}";
    static readonly styles: import("lit").CSSResult[];
    /** Set when the combo box dropdown is open */
    open: boolean;
    /** Rerenders the dropdown */
    reflow: boolean;
    announceTemplate: string;
    /** Sets selected option */
    activeIndex: number | null;
    data: string[];
    private ariaAnnounceText;
    activeElement?: HTMLLIElement | null;
    droplist?: HTMLElement | null;
    render(): import("lit-html").TemplateResult<1>;
    private _onKeyup;
    private _optionSelected;
    private _select;
    protected _renderOptions(): void;
    /**
     * Handle state changes when active droplist item has been changed
     */
    protected _activeIndexChanged(): void;
}
declare global {
    interface HTMLElementTagNameMap {
        'pfe-search-droplist': PfeSearchDroplist;
    }
}
